# Sportradar API
Lightweight wrapper for [Sportradar API](https://developer.sportradar.com/docs/read/Home)

## Set up
1. Register on [Sportradar Developer](https://developer.sportradar.com/member/register)
2. Generate an API Key

## Installation
````bash
pip install sportradar-api
````

## Usage

````python
from sportradar_api import SoccerExtended

sportradar = SoccerExtended(api_key='SPORTRADAR_API_KEY')
````